@@ -2,9 +2,7 @@ test_that("Test message on cff", {
   expect_snapshot(def <- cff("abcde"))
 
   expect_identical(def, cff())
-  nocff <- system.file("examples/CITATION_skeleton.cff",
-    package = "cffR"
-  )
+  nocff <- system.file("examples/CITATION_skeleton.cff", package = "cffR")
   expect_snapshot(afile <- cff(nocff))
 
   expect_identical(afile, cff())
@@ -12,9 +10,7 @@ test_that("Test message on cff", {
 
 
 test_that("Walk trough full lifecycle", {
-  complete <- system.file("examples/CITATION_complete.cff",
-    package = "cffr"
-  )
+  complete <- system.file("examples/CITATION_complete.cff", package = "cffr")
 
   # Read
   read <- cff_read(complete)
@@ -29,8 +25,6 @@ test_that("Walk trough full lifecycle", {
   expect_true(length((setdiff(names(read), names(modify)))) == 0)
   expect_false(read$title == modify$title)
 
-
-
   # Write
   tmp <- tempfile(fileext = ".cff")
   cff_write(modify, outfile = tmp, validate = FALSE, verbose = FALSE)
@@ -43,9 +37,7 @@ test_that("Walk trough full lifecycle", {
 })
 
 test_that("Recursive parsing", {
-  complete <- system.file("examples/CITATION_complete.cff",
-    package = "cffr"
-  )
+  complete <- system.file("examples/CITATION_complete.cff", package = "cffr")
 
   # Read
   expect_snapshot(read <- cff(complete))
@@ -69,41 +61,61 @@ test_that("Fuzzy matching of keys on cff", {
     messange = "Fix my keys"
   ))
 
-  expect_snapshot(cffobj <- cff(
-    tittle = "a",
-    cff_version = "1.2.0", version = "200",
-    messange = "aa",
-    anthor = list(list(
-      "family-names" = "a",
-      "given-names" = "b"
-    ))
-  ))
+  expect_snapshot(
+    cffobj <- cff(
+      tittle = "a",
+      cff_version = "1.2.0",
+      version = "200",
+      messange = "aa",
+      anthor = list(list(
+        "family-names" = "a",
+        "given-names" = "b"
+      ))
+    )
+  )
 
   expect_true(is_cff(cffobj))
   expect_true(cff_validate(cffobj, verbose = FALSE))
 })
 
 test_that("duplicated", {
-  expect_snapshot(ss <- cff(
-    tittle = "a", tittle = "ar",
-    version = "200",
-    messange = "Fix my keys"
-  ))
+  expect_snapshot(
+    ss <- cff(
+      tittle = "a",
+      tittle = "ar",
+      version = "200",
+      messange = "Fix my keys"
+    )
+  )
 
   expect_s3_class(ss, "cff")
   expect_length(ss, 3)
 })
 
 test_that("unnamed", {
-  expect_snapshot(ss <- cff(
-    path = "a", "200", "Fix my keys"
-  ), error = TRUE)
+  expect_snapshot(
+    ss <- cff(
+      path = "a",
+      "200",
+      "Fix my keys"
+    ),
+    error = TRUE
+  )
 
   expect_snapshot(s1 <- cff(path = NULL, title = "a", "b", version = 1))
-  expect_snapshot(s2 <- cff(
-    path = NULL, title = "a", "aa", "bb", "cc",
-    "b", version = 1, "h", "j"
-  ))
+  expect_snapshot(
+    s2 <- cff(
+      path = NULL,
+      title = "a",
+      "aa",
+      "bb",
+      "cc",
+      "b",
+      version = 1,
+      "h",
+      "j"
+    )
+  )
 
   expect_identical(s1, s2)
 })
