@@ -12,11 +12,11 @@ test_that("Test in mock package", {
   setwd(new_dir)
 
   # Move files
-  file.copy(system.file("examples/DESCRIPTION_many_urls", package = "cffr"),
+  file.copy(
+    system.file("examples/DESCRIPTION_many_urls", package = "cffr"),
     to = "DESCRIPTION"
   )
 
-
   # Create Rbuildignore
   file.create(".Rbuildignore", showWarnings = FALSE)
   expect_true(file_exist_abort(".Rbuildignore"))
@@ -33,7 +33,6 @@ test_that("Test in mock package", {
     "update-citation-cff.yaml"
   )))
 
-
   # Revert to initial wd
   setwd(current_dir)
 
