@@ -1,7 +1,5 @@
 test_that("Validate full CITATION.cff", {
-  full <- system.file("examples/CITATION_complete.cff",
-    package = "cffr"
-  )
+  full <- system.file("examples/CITATION_complete.cff", package = "cffr")
 
   # From object
   fcff <- cff_read(full)
@@ -15,16 +13,12 @@ test_that("Validate full CITATION.cff", {
 })
 
 test_that("Validate minimal CITATION.cff", {
-  full <- system.file("examples/CITATION_skeleton.cff",
-    package = "cffr"
-  )
+  full <- system.file("examples/CITATION_skeleton.cff", package = "cffr")
   expect_true(cff_validate(full, verbose = FALSE))
 })
 
 test_that("Validate error CITATION.cff", {
-  err <- system.file("examples/CITATION_error.cff",
-    package = "cffr"
-  )
+  err <- system.file("examples/CITATION_error.cff", package = "cffr")
   # From cff
   ferr <- cff_read(err)
   expect_snapshot(tab <- cff_validate(ferr))
@@ -44,14 +38,10 @@ test_that("Validate cffr objects from installed packages", {
 
 
 test_that("Validate error for invalid input", {
-  nocff <- system.file("CITATION",
-    package = "cffr"
-  )
+  nocff <- system.file("CITATION", package = "cffr")
   expect_error(cff_validate(nocff))
 
-  nofile <- system.file("examples/no_file_here",
-    package = "cffr"
-  )
+  nofile <- system.file("examples/no_file_here", package = "cffr")
   expect_error(cff_validate(nofile))
 })
 
